Overview – Samplics Documentation
Description: Documentation of the Python package Samplics for statistical design and analysis of complex samples

# Overview

Often the goal of conducting a survey is to estimate parameters of the target population from the survey sample. To appropriately estimate uncertainties associated with the sample estimates, the complex design must be taken into account.

In this tutorial, we demonstrate how to use the Samplics APIs to produce point estimates of mean, total, proportion and ratio parameters as well as their associated Taylor-based and replication-based measures of uncertainty.

Section 1: Taylor-based Estimation
Section 2: Replicate-based Estimation

Wolter (2007) provides a self-contained description of a number of techniques for variance estimation both Taylor and replication based.

## References

Wolter, Kirk M. 2007. Introduction to Variance Estimation, 2nd edn. Springer-Verlag New York, Inc.